@@ -1,4 +1,4 @@
-# Copyright 2020 QuantumBlack Visual Analytics Limited
+# Copyright 2021 QuantumBlack Visual Analytics Limited
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -91,7 +91,7 @@ class HoloviewsWriter(AbstractVersionedDataSet):
                 All defaults are preserved, except `mode`, which is set to `wb` when saving.
             credentials: Credentials required to get access to the underlying filesystem.
                 E.g. for ``S3FileSystem`` it should look like:
-                `{'client_kwargs': {'aws_access_key_id': '<id>', 'aws_secret_access_key': '<key>'}}`
+                `{'key': '<id>', 'secret': '<key>'}}`
             save_args: Extra save args passed to `holoviews.save()`. See
                 http://holoviews.org/reference_manual/holoviews.util.html#holoviews.util.save
             version: If specified, should be an instance of
@@ -105,6 +105,8 @@ class HoloviewsWriter(AbstractVersionedDataSet):
         _fs_open_args_save.setdefault("mode", "wb")
 
         protocol, path = get_protocol_and_path(filepath, version)
+        if protocol == "file":
+            _fs_args.setdefault("auto_mkdir", True)
 
         self._protocol = protocol
         self._fs = fsspec.filesystem(self._protocol, **_credentials, **_fs_args)
