@@ -1,4 +1,4 @@
-# Copyright 2020 QuantumBlack Visual Analytics Limited
+# Copyright 2021 QuantumBlack Visual Analytics Limited
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -34,6 +34,7 @@ __all__ = [
     "FeatherDataSet",
     "GBQTableDataSet",
     "ExcelDataSet",
+    "AppendableExcelDataSet",
     "HDFDataSet",
     "JSONDataSet",
     "ParquetDataSet",
@@ -47,6 +48,8 @@ with suppress(ImportError):
     from .csv_dataset import CSVDataSet  # NOQA
 with suppress(ImportError):
     from .excel_dataset import ExcelDataSet  # NOQA
+with suppress(ImportError):
+    from .appendable_excel_dataset import AppendableExcelDataSet  # NOQA
 with suppress(ImportError):
     from .feather_dataset import FeatherDataSet  # NOQA
 with suppress(ImportError):
