@@ -36,21 +36,30 @@ import webbrowser
 from collections import defaultdict
 from copy import deepcopy
 from pathlib import Path
-from typing import Any, List
+from typing import Any, Sequence
 
 import click
 import pkg_resources
+from click.utils import get_os_args
 
 # pylint: disable=unused-import
 import kedro.config.default_logger  # noqa
 from kedro import __version__ as version
+from kedro.framework.cli.catalog import catalog_cli
+from kedro.framework.cli.hooks import CLIHooksManager
+from kedro.framework.cli.jupyter import jupyter_cli
+from kedro.framework.cli.pipeline import pipeline_cli
+from kedro.framework.cli.project import project_group
 from kedro.framework.cli.starters import create_cli
-from kedro.framework.cli.utils import CommandCollection, KedroCliError, _add_src_to_path
+from kedro.framework.cli.utils import (
+    CONTEXT_SETTINGS,
+    ENTRY_POINT_GROUPS,
+    CommandCollection,
+    KedroCliError,
+    load_entry_points,
+)
 from kedro.framework.context.context import load_context
-from kedro.framework.project import configure_project
-from kedro.framework.startup import _get_project_metadata, _is_project
-
-CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"])
+from kedro.framework.startup import _is_project, bootstrap_project
 
 LOGO = rf"""
  _            _
@@ -64,24 +73,16 @@ v{version}
 
 @click.group(context_settings=CONTEXT_SETTINGS, name="Kedro")
 @click.version_option(version, "--version", "-V", help="Show version and exit")
-def cli():
-    """Kedro is a CLI for creating and using Kedro projects
-    For more information, type ``kedro info``.
+def cli():  # pragma: no cover
+    """Kedro is a CLI for creating and using Kedro projects. For more
+    information, type ``kedro info``.
 
-    When inside a Kedro project (created with ``kedro new``) commands
-    from the project's ``cli.py`` file will also be available here.
+    When inside a Kedro project (created with ``kedro new``) commands from
+    the project's ``cli.py`` file will also be available here.
     """
     pass
 
 
-ENTRY_POINT_GROUPS = {
-    "global": "kedro.global_commands",
-    "project": "kedro.project_commands",
-    "init": "kedro.init",
-    "line_magic": "kedro.line_magic",
-}
-
-
 @cli.command()
 def info():
     """Get more information about kedro.
@@ -159,29 +160,6 @@ def get_project_context(
     return deepcopy(value)
 
 
-def load_entry_points(name: str) -> List[str]:
-    """Load package entry point commands.
-
-    Args:
-        name: The key value specified in ENTRY_POINT_GROUPS.
-
-    Raises:
-        KedroCliError: If loading an entry point failed.
-
-    Returns:
-        List of entry point commands.
-
-    """
-    entry_points = pkg_resources.iter_entry_points(group=ENTRY_POINT_GROUPS[name])
-    entry_point_commands = []
-    for entry_point in entry_points:
-        try:
-            entry_point_commands.append(entry_point.load())
-        except Exception as exc:
-            raise KedroCliError(f"Loading {name} commands from {entry_point}") from exc
-    return entry_point_commands
-
-
 def _init_plugins():
     group = ENTRY_POINT_GROUPS["init"]
     for entry_point in pkg_resources.iter_entry_points(group=group):
@@ -192,37 +170,100 @@ def _init_plugins():
             raise KedroCliError(f"Initializing {entry_point}") from exc
 
 
+class KedroCLI(CommandCollection):
+    """A CommandCollection class to encapsulate the KedroCLI command
+    loading.
+    """
+
+    def __init__(self, project_path: Path):
+        self._metadata = None  # running in package mode
+        if _is_project(project_path):
+            self._metadata = bootstrap_project(project_path)
+        self._cli_hook_manager = CLIHooksManager()
+
+        super().__init__(
+            ("Global commands", self.global_groups),
+            ("Project specific commands", self.project_groups),
+        )
+
+    def main(
+        self,
+        args=None,
+        prog_name=None,
+        complete_var=None,
+        standalone_mode=True,
+        **extra,
+    ):
+        if self._metadata:
+            extra.update(obj=self._metadata)
+
+        # This is how click's internals parse sys.argv, which include the command,
+        # subcommand, arguments and options. click doesn't store this information anywhere
+        # so we have to re-do it.
+        # https://github.com/pallets/click/blob/master/src/click/core.py#L942-L945
+        args = get_os_args() if args is None else list(args)
+        self._cli_hook_manager.hook.before_command_run(
+            project_metadata=self._metadata, command_args=args,
+        )
+
+        super().main(
+            args=args,
+            prog_name=prog_name,
+            complete_var=complete_var,
+            standalone_mode=standalone_mode,
+            **extra,
+        )
+
+    @property
+    def global_groups(self) -> Sequence[click.MultiCommand]:
+        """Property which loads all global command groups from plugins and
+        combines them with the built-in ones (eventually overriding the
+        built-in ones if they are redefined by plugins).
+        """
+        return [cli, create_cli, *load_entry_points("global")]
+
+    @property
+    def project_groups(self) -> Sequence[click.MultiCommand]:
+        """Property which loads all project command groups from the
+        project and the plugins, then combines them with the built-in ones.
+        Built-in commands can be overridden by plugins, which can be
+        overridden by the project's cli.py.
+        """
+        if not self._metadata:
+            return []
+
+        built_in = [
+            catalog_cli,
+            jupyter_cli,
+            pipeline_cli,
+            project_group,
+        ]
+
+        plugins = load_entry_points("project")
+
+        try:
+            project_cli = importlib.import_module(f"{self._metadata.package_name}.cli")
+            # fail gracefully if cli.py does not exist
+        except ModuleNotFoundError:
+            # return only built-in commands and commands from plugins
+            # (plugins can override built-in commands)
+            return [*built_in, *plugins]
+
+        # fail badly if cli.py exists, but has no `cli` in it
+        if not hasattr(project_cli, "cli"):
+            raise KedroCliError(
+                f"Cannot load commands from {self._metadata.package_name}.cli"
+            )
+        user_defined = project_cli.cli  # type: ignore
+        # return built-in commands, plugin commands and user defined commands
+        # (overriding happens as follows built-in < plugins < cli.py)
+        return [*built_in, *plugins, user_defined]
+
+
 def main():  # pragma: no cover
     """Main entry point. Look for a ``cli.py``, and, if found, add its
     commands to `kedro`'s before invoking the CLI.
     """
     _init_plugins()
-    global_groups = [cli, create_cli]
-    global_groups.extend(load_entry_points("global"))
-    project_groups = []
-    cli_context = dict()
-
-    path = Path.cwd()
-    if _is_project(path):
-        # load project commands from cli.py
-        metadata = _get_project_metadata(path)
-        package_name = metadata.package_name
-        cli_context = dict(obj=metadata)
-        _add_src_to_path(metadata.source_dir, path)
-        configure_project(package_name)
-
-        project_groups.extend(load_entry_points("project"))
-
-        try:
-            project_cli = importlib.import_module(f"{package_name}.cli")
-            project_groups.append(project_cli.cli)
-        except Exception as exc:
-            raise KedroCliError(
-                f"Cannot load commands from {package_name}.cli"
-            ) from exc
-
-    cli_collection = CommandCollection(
-        ("Global commands", global_groups),
-        ("Project specific commands", project_groups),
-    )
-    cli_collection(**cli_context)
+    cli_collection = KedroCLI(project_path=Path.cwd())
+    cli_collection()
