@@ -30,6 +30,7 @@
 
 import logging
 import logging.config
+import os
 import subprocess
 import traceback
 from copy import deepcopy
@@ -40,9 +41,12 @@ import click
 
 from kedro import __version__ as kedro_version
 from kedro.framework.context import KedroContext
-from kedro.framework.context.context import _convert_paths_to_absolute_posix
+from kedro.framework.context.context import (
+    KedroContextError,
+    _convert_paths_to_absolute_posix,
+)
 from kedro.framework.hooks import get_hook_manager
-from kedro.framework.project import settings
+from kedro.framework.project import configure_project, pipelines, settings
 from kedro.framework.session.store import BaseSessionStore
 from kedro.io.core import generate_timestamp
 from kedro.runner import AbstractRunner, SequentialRunner
@@ -172,6 +176,14 @@ class KedroSession:
             A new ``KedroSession`` instance.
         """
         # pylint: disable=protected-access
+
+        # this is to make sure that for workflows that manually create session
+        # without going through one of our known entrypoints, e.g. some plugins like kedro-airflow,
+        # the project is still properly configured. This is for backward compatibility
+        # and should be removed in 0.18.
+        if package_name is not None:
+            configure_project(package_name)
+
         session = cls(
             package_name=package_name,
             project_path=project_path,
@@ -192,6 +204,7 @@ class KedroSession:
         if ctx:
             session_data["cli"] = _jsonify_cli_context(ctx)
 
+        env = env or os.getenv("KEDRO_ENV")
         if env:
             session_data["env"] = env
 
@@ -326,6 +339,8 @@ class KedroSession:
             load_versions: An optional flag to specify a particular dataset
                 version timestamp to load.
         Raises:
+            KedroContextError: If the named or `__default__` pipeline is not
+                defined by `register_pipelines`.
             Exception: Any uncaught exception during the run will be re-raised
                 after being passed to ``on_pipeline_error`` hook.
         Returns:
@@ -341,7 +356,17 @@ class KedroSession:
         extra_params = self.store.get("extra_params") or {}
         context = self.load_context()
 
-        pipeline = context._get_pipeline(name=pipeline_name)
+        name = pipeline_name or "__default__"
+
+        try:
+            pipeline = pipelines[name]
+        except (TypeError, KeyError) as exc:
+            raise KedroContextError(
+                f"Failed to find the pipeline named '{name}'. "
+                f"It needs to be generated and returned "
+                f"by the 'register_pipelines' function."
+            ) from exc
+
         filtered_pipeline = context._filter_pipeline(
             pipeline=pipeline,
             tags=tags,
